This package contains API code for calling the `ESGF Search API`_ within
client code.  The initial implementation is in Python.

Please submit bugs and feature requests through the bug tracker on
github.  Pull requests are always welcome.

Full `documentation`_ is available on ReadTheDocs or in the docs directory.

.. _`ESGF Search API`: http://esgf.org/wiki/ESGF_Search_API
.. _`documentation`: http://esgf-pyclient.readthedocs.org
